(self.webpackChunkjupyter_weav_app_one=self.webpackChunkjupyter_weav_app_one||[]).push([[778],{778:(e,t,a)=>{"use strict";a.r(t),a.d(t,{default:()=>d});var n=a(120),c=a(383),l=a(271),r=a.n(l);const i=()=>r().createElement("div",{style:{textAlign:"center"}},r().createElement("h1",{style:{color:"blue"}},"Welcome to WEAV AI"),r().createElement("a",{href:"https://weav.ai/",target:"_blank",title:"weav homepage"},r().createElement("img",{height:"100",width:"100",src:"https://img1.wsimg.com/isteam/ip/5944b92b-9cdf-4e95-9400-d95080c03bdb/Weav%20Logo%20-%200.6.png/:/rs=h:640/ll",alt:"weav homepage"})));class s extends n.ReactWidget{constructor(){super(),this.addClass("jp-ReactWidget")}render(){return r().createElement(i,null)}}var o;!function(e){e.create="create-react-widget"}(o||(o={}));const d={id:"react-widget",autoStart:!0,optional:[c.ILauncher],activate:(e,t)=>{const{commands:a}=e,c=o.create;a.addCommand(c,{caption:"WEAV AI launcher",label:"WEAV AI",icon:e=>(e.isPalette,null),execute:()=>{const t=new s,a=new n.MainAreaWidget({content:t});a.title.label="WEAV AI",e.shell.add(a,"main")}}),t&&t.add({command:c})}}}}]);